unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, FileCtrl, ExtCtrls, ID3v2;

type
  TMainForm = class(TForm)
    DriveList: TDriveComboBox;
    FolderList: TDirectoryListBox;
    FileList: TFileListBox;
    CloseButton: TButton;
    InfoBevel: TBevel;
    IconImage: TImage;
    TagExistsLabel: TLabel;
    TagExistsText: TEdit;
    VersionLabel: TLabel;
    VersionText: TEdit;
    SizeLabel: TLabel;
    SizeText: TEdit;
    TitleLabel: TLabel;
    TitleText: TEdit;
    ArtistLabel: TLabel;
    ArtistText: TEdit;
    AlbumLabel: TLabel;
    AlbumText: TEdit;
    TrackLabel: TLabel;
    TrackText: TEdit;
    YearLabel: TLabel;
    YearText: TEdit;
    GenreLabel: TLabel;
    GenreText: TEdit;
    CommentLabel: TLabel;
    CommentText: TEdit;
    procedure CloseButtonClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FileListChange(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private declarations }
    FileTag: TID3v2;
    procedure ClearAll;
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

procedure TMainForm.ClearAll;
begin
  { Clear all captions }
  TagExistsText.Text := '';
  VersionText.Text := '';
  SizeText.Text := '';
  TitleText.Text := '';
  ArtistText.Text := '';
  AlbumText.Text := '';
  TrackText.Text := '';
  YearText.Text := '';
  GenreText.Text := '';
  CommentText.Text := '';
end;

procedure TMainForm.CloseButtonClick(Sender: TObject);
begin
  { Exit }
  Close;
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  { Create object and clear captions }
  FileTag := TID3v2.Create;
  ClearAll;
end;

procedure TMainForm.FileListChange(Sender: TObject);
begin
  { Clear captions }
  ClearAll;
  if FileList.FileName = '' then exit;
  if FileExists(FileList.FileName) then
    { Load tag data }
    if FileTag.ReadFromFile(FileList.FileName) then
      if FileTag.Exists then
      begin
        { Fill captions }
        TagExistsText.Text := 'Yes';
        VersionText.Text := '2.' + IntToStr(FileTag.VersionID) + '.x';
        SizeText.Text := IntToStr(FileTag.Size) + ' bytes';
        TitleText.Text := FileTag.Title;
        ArtistText.Text := FileTag.Artist;
        AlbumText.Text := FileTag.Album;
        if FileTag.Track > 0 then TrackText.Text := IntToStr(FileTag.Track);
        YearText.Text := FileTag.Year;
        GenreText.Text := FileTag.Genre;
        CommentText.Text := FileTag.Comment;
      end
      else
        { Tag not found }
        TagExistsText.Text := 'No'
    else
      { Read error }
      ShowMessage('Can not read tag from the file: ' + FileList.FileName)
  else
    { File does not exist }
    ShowMessage('The file does not exist: ' + FileList.FileName);
end;

procedure TMainForm.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  { Free memory }
  FileTag.Free;
end;

end.
